import { feature } from "topojson";
import {select,
        json,
        geoPath, 
        geoMercator,
        zoom,
        event} from "d3";

const svg = d3.select('svg');
const height = +svg.attr('height');
const width = +svg.attr('width');
const projection = geoMercator().scale(4000).translate([-5850, 2000])
const pathGenerator = geoPath().projection(projection);
const g= svg.append('g');
const TipsText = "Tips: Hover on any area to see - Sales Data";
const HeaderText = "Sales Data on Map";

svg.style('background-color',"white");
svg.append('text').attr('y',40).attr('x',300).text(HeaderText);
svg.append('text').attr('y',height-150).attr('x',width-280).text(TipsText).attr('class',"tips");
svg.call(zoom().on('zoom',()=>{
	console.log("Zooming..");
  g.attr('transform',event.transform);
}));


// Parsing Data
Promise.all([
  json("salesData.json"),
	json("https://raw.githubusercontent.com/techslides/D3-Maps/master/data/world/country/Bangladesh.topo.json")
]).then(([salesData,topoJsonData])=> {
  console.log(topoJsonData);
    // Get Sales information on hover
      const getSalesInformation =(d)=> {
        const districtName = d.properties.name;
        let selectedDistrict = salesData.filter(obj => {
            return obj.name === districtName;
        })
        let outputString = `City: ${selectedDistrict[0].name}\nYearly Sales: ${selectedDistrict[0].yearly} \nMonthly Sales: ${selectedDistrict[0].monthly} \nWeekly Sales: ${selectedDistrict[0].weekly}`;  
        return outputString;
    }

    // Parsing feature from Data
    const subdistrict = feature(topoJsonData, topoJsonData.objects["map"]);  

    // Construct map path from feature data( subdistrict);
    const dist = g.selectAll('path').data(subdistrict.features).enter().append('path')
            .attr('class', 'district')
            .attr('d', pathGenerator);
        dist.append('title')
            .text((d)=>getSalesInformation(d));
});

